\name{DressEnsemble}
\alias{DressEnsemble}
\title{Ensemble dressing}
\description{
  Transform an ensemble forecast to a continuous forecast distribution by kernel dressing.
}
\usage{
DressEnsemble(ens, dressing.method, parameters)
}
\arguments{
  \item{ens}{matrix, N rows, K columns. An archive of K-member ensemble forecasts for N time instances.}
  \item{dressing.method}{string. One of "silverman" (default), "akd", "akd.fit". See Details.} 
  \item{parameters}{list. Contains the parameters for the dressing method. See Details.}
}
\value{
The function returns an object of class `dressed.ensemble`, which is a list with elements

ens: matrix, N rows, K columns. The element ens[n,k] is the mean of the `k`-th kernel at time instance `n`.

ker.wd: matrix, N rows, K columns. The element ker.wd[n,k] is the standard deviation of the `k`-th kernel at time instance `n`.

ker.type: string. Type of the dressing kernel.
}
\details{
The dressing methods currently implemented and their required parameters are:

"silverman" (default): No parameters are given. At time instance `n` each ensemble member is replaced by a Gaussian kernel with mean ens[n, k] and variance (4 / 3 / K)^0.4 * var(ens[n, ]). This method is called "Silverman's rule of thumb" and provides a simple non-parametric method for smoothing a discrete ensemble.

"akd": Affine Kernel Dressing. The required parameters are list(r1, r2, a, s1, s2). The `k`-th ensemble member at time instance `n` is dressed with a Gaussian kernel with mean r1 + r2 * mean(ens[n,]) + a * ens[n, k] and variance (4 / 3 / K)^0.4 * (s1 + s2 * a^2 * var(ens[n,])). Negative variances are set to zero. Note that parameters = list(r1=0, r2=0, a=1, s1=0, s2=1) yields the same dressed ensemble as dressing.method="silverman".

"akd.fit": Affine Kernel Dressing with fitted parameters. The required parameters is list(obs), where `obs` is a vector of observations which are used to optimize the parameters r1, r2, a, s1, s2 by CRPS minimization. See ?FitAkdParameters for more information.
}
\examples{
  # Example:
  ens <- matrix(rnorm(500),100,5)
  obs <- rnorm(100)
  d.silverman <- DressEnsemble(ens)
  d.akd <- DressEnsemble(ens, dressing.method="akd", 
                         parameters=list(r1=0, r2=0, a=1, 
                                         s1=0, s2=0))
  d.akd.fit <- DressEnsemble(ens, dressing.method="akd.fit", 
                             parameters=list(obs=obs))
}

\references{
Silverman, B.W. (1998). Density Estimation for Statistics and Data Analysis. London: Chapman & Hall/CRC. ISBN 0-412-24620-1.

Broecker J. and Smith L. (2008). From ensemble forecasts to predictive distribution functions. Tellus (2008), 60A, 663--678. DOI 10.1111/j.1600-0870.2008.00333.x.

}

